==> 3.5.1.tar.gz: scsi2sd/software/SCSI2SD/v3/SCSI2SD.cydsn/Generated_Source/PSoC5/SD_MOSI.c <==
/*******************************************************************************
* File Name: SD_MOSI.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SD_MOSI.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 SD_MOSI__PORT == 15 && ((SD_MOSI__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: SD_MOSI_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void SD_MOSI_Write(uint8 value) 
{
    uint8 staticBits = (SD_MOSI_DR & (uint8)(~SD_MOSI_MASK));
    SD_MOSI_DR = staticBits | ((uint8)(value << SD_MOSI_SHIFT) & SD_MOSI_MASK);
}


/*******************************************************************************
* Function Name: SD_MOSI_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void SD_MOSI_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SD_MOSI_0, mode);
}


/*******************************************************************************
* Function Name: SD_MOSI_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SD_MOSI_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SD_MOSI_Read(void) 
{
    return (SD_MOSI_PS & SD_MOSI_MASK) >> SD_MOSI_SHIFT;
}


/*******************************************************************************
* Function Name: SD_MOSI_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SD_MOSI_ReadDataReg(void) 
{
    return (SD_MOSI_DR & SD_MOSI_MASK) >> SD_MOSI_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SD_MOSI_INTSTAT) 

    /*******************************************************************************
    * Function Name: SD_MOSI_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SD_MOSI_ClearInterrupt(void) 
    {
        return (SD_MOSI_INTSTAT & SD_MOSI_MASK) >> SD_MOSI_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */

==> v4.02.04.tar.gz: scsi2sd/software/SCSI2SD/v3/SCSI2SD.cydsn/Generated_Source/PSoC5/SD_MOSI.c <==
/*******************************************************************************
* File Name: SD_MOSI.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SD_MOSI.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 SD_MOSI__PORT == 15 && ((SD_MOSI__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: SD_MOSI_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void SD_MOSI_Write(uint8 value) 
{
    uint8 staticBits = (SD_MOSI_DR & (uint8)(~SD_MOSI_MASK));
    SD_MOSI_DR = staticBits | ((uint8)(value << SD_MOSI_SHIFT) & SD_MOSI_MASK);
}


/*******************************************************************************
* Function Name: SD_MOSI_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  SD_MOSI_DM_STRONG     Strong Drive 
*  SD_MOSI_DM_OD_HI      Open Drain, Drives High 
*  SD_MOSI_DM_OD_LO      Open Drain, Drives Low 
*  SD_MOSI_DM_RES_UP     Resistive Pull Up 
*  SD_MOSI_DM_RES_DWN    Resistive Pull Down 
*  SD_MOSI_DM_RES_UPDWN  Resistive Pull Up/Down 
*  SD_MOSI_DM_DIG_HIZ    High Impedance Digital 
*  SD_MOSI_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void SD_MOSI_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(SD_MOSI_0, mode);
}


/*******************************************************************************
* Function Name: SD_MOSI_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro SD_MOSI_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 SD_MOSI_Read(void) 
{
    return (SD_MOSI_PS & SD_MOSI_MASK) >> SD_MOSI_SHIFT;
}


/*******************************************************************************
* Function Name: SD_MOSI_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 SD_MOSI_ReadDataReg(void) 
{
    return (SD_MOSI_DR & SD_MOSI_MASK) >> SD_MOSI_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(SD_MOSI_INTSTAT) 

    /*******************************************************************************
    * Function Name: SD_MOSI_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 SD_MOSI_ClearInterrupt(void) 
    {
        return (SD_MOSI_INTSTAT & SD_MOSI_MASK) >> SD_MOSI_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
